@@ -5,21 +5,56 @@ use App::RPi::EnvUI::Event;
 use Data::Dumper;
 use DateTime;
 use JSON::XS;
+use Mock::Sub no_warnings => 1;
 use RPi::WiringPi::Constant qw(:all);
 
-our $VERSION = '0.21';
+our $VERSION = '0.22';
+
+# these are mocked sub handles for when we're in testing mode
+
+my $temp_sub;
+my $hum_sub;
+my $wp_sub;
 
 sub new {
     my $self = bless {}, shift;
     %$self = @_;
 
-    # check if we're testing or not. If so, bypass the loading of the
-    # RPi::DHT11 and WiringPi::API modules, and set up a fake sensor
+    # check if we're testing or not. If a testing.lck file is present, its a UI
+    # test run, and we need to bypass the loading of the
+    # RPi::DHT11 and WiringPi::API modules, and set up a fake sensor within
+    # this package (other tests API/DB should mock the subs there)
+
+    #FIXME: testing 1 and testing 2 needs to be made more descriptive
 
     if (-e 't/testing.lck' || $self->{testing}){
+        if (-e 't/testing.lck') {
+            $self->{testing} = 1;
+
+            my $mock = Mock::Sub->new;
+
+            $temp_sub = $mock->mock(
+                'RPi::DHT11::temp',
+                return_value => 80
+            );
+
+            $hum_sub = $mock->mock(
+                'RPi::DHT11::humidity',
+                return_value => 20
+            );
+
+            $wp_sub = $mock->mock(
+                'App::RPi::EnvUI::API::write_pin',
+                return_value => 'ok'
+            );
+        }
+
         warn "API in test mode\n";
+
         $self->{sensor} = bless {}, 'RPi::DHT11';
-        $self->{db} = App::RPi::EnvUI::DB->new(testing => 1);
+        $self->{db} = App::RPi::EnvUI::DB->new(
+            testing => $self->{testing}
+        );
     }
     else {
         if (! exists $INC{'WiringPi/API.pm'}){
@@ -80,14 +115,14 @@ sub switch {
 }
 sub action_light {
     my $self = shift;
-    my $light = shift;
+
     my $now = DateTime->now(time_zone => $self->_config_core('time_zone'));
 
-    my ($on_hour, $on_min) = split /:/, $light->{on_at};
+    my ($on_hour, $on_min) = split /:/, $self->_config_light('on_at');
 
-    if ($now->hour > $on_hour || ($now->hour == $on_hour && $now->minute >= $on_min)){
+    if ($now->hour > $on_hour || ($now->hour == $on_hour && $now->minute >= $on_min && ! $self->_config_light('on_since'))){
         $self->{db}->update('light', 'value', time(), 'id', 'on_since');
-        $self->aux_state(_config_control('light_aux'), ON);
+        $self->aux_state($self->_config_control('light_aux'), ON);
 
         #
         # turn light on here!
@@ -103,7 +138,7 @@ sub action_light {
 
         if ($remaining >= $on_secs){
             $self->{db}->update('light', 'value', 0, 'id', 'on_since');
-            $self->aux_state(_config_control('light_aux'), OFF);
+            $self->aux_state($self->_config_control('light_aux'), OFF);
 
             #
             # turn light off here!
@@ -118,16 +153,14 @@ sub action_humidity {
     my $limit = $self->_config_control('humidity_limit');
     my $min_run = $self->_config_control('humidity_aux_on_time');
 
-    my $x = $self->aux_override($aux_id);
-
     if (! $self->aux_override($aux_id)) {
-        if ($humidity < $limit && $self->aux_time( $aux_id ) == 0) {
-            $self->aux_state( $aux_id, HIGH );
-            $self->aux_time( $aux_id, time );
+        if ($humidity < $limit && $self->aux_time($aux_id) == 0) {
+            $self->aux_state($aux_id, HIGH);
+            $self->aux_time($aux_id, time());
         }
-        elsif ($humidity >= $limit && $self->aux_time( $aux_id ) >= $min_run) {
-            $self->aux_state( $aux_id, LOW );
-            $self->aux_time( $aux_id, 0 );
+        if ($humidity >= $limit && $self->aux_time($aux_id) >= $min_run) {
+            $self->aux_state($aux_id, LOW);
+            $self->aux_time($aux_id, 0);
         }
     }
 }
@@ -139,11 +172,11 @@ sub action_temp {
     my $min_run = $self->_config_control('temp_aux_on_time');
 
     if (! $self->aux_override($aux_id)){
-        if ($temp >= $limit && $self->aux_time($aux_id) == 0){
+        if ($temp > $limit && $self->aux_time($aux_id) == 0){
             $self->aux_state($aux_id, HIGH);
             $self->aux_time($aux_id, time);
         }
-        elsif ($temp < $limit && $self->aux_time($aux_id) >= $min_run){
+        elsif ($temp <= $limit && $self->aux_time($aux_id) >= $min_run){
             $self->aux_state($aux_id, LOW);
             $self->aux_time($aux_id, 0);
         }
@@ -193,7 +226,8 @@ sub aux_time {
     }
 
     my $on_time = $self->aux($aux_id)->{on_time};
-    return $on_time == 0 ? 0 : time - $on_time;
+    my $on_length = time() - $on_time;
+    return $on_time == 0 ? 0 : $on_length;
 }
 sub aux_override {
     my $self = shift;
@@ -266,8 +300,14 @@ sub _config_light {
 }
 sub _config_water {
     my $self = shift;
+    my $want = shift;
+
     my $water = $self->{db}->config_water;
 
+    if (defined $want){
+        return $water->{$want}{value};
+    }
+
     my %conf;
 
     for (keys %$water){
@@ -350,7 +390,13 @@ sub _parse_config {
     # aux entries are suffixed with a number
 
     for my $directive (keys %{ $conf->{aux} }){
-        $self->{db}->update('aux', 'value', $conf->{aux}{$directive}, 'id', $directive);
+        $self->{db}->update(
+            'aux',
+            'value',
+            $conf->{aux}{$directive},
+            'id',
+            $directive
+        );
     }
 }
 sub _reset {
@@ -375,7 +421,8 @@ __END__
 
 =head1 NAME
 
-App::RPi::EnvUI - One-page asynchronous grow room environment control web application
+App::RPi::EnvUI - One-page asynchronous grow room environment control web
+application
 
 =head1 SYNOPSIS
 
