@@ -5,7 +5,7 @@ use DateTime;
 use DBI;
 use RPi::WiringPi::Constant qw(:all);
 
-our $VERSION = '0.21';
+our $VERSION = '0.22';
 
 #FIXME: the following will have to be cleaned up into a conditional
 # we create a db handle globally so that if subsequent calls to new() are done,
@@ -24,9 +24,28 @@ sub new {
     my $self = bless {}, shift;
     my %args = @_;
 
-    if (-e 't/testing.lck' || (defined $args{testing} && $args{testing})){
-        $self->{testing} = 1;
-        $self->{db} = $dbh;
+    #FIXME: testing 1 and testing 2 needs to be made more descriptive
+    # 1: testing for web ui and non-event tests
+    # 2: testing for separate procs (events)
+
+    if (-e 't/testing.lck' || defined $args{testing}){
+
+        warn "DB in test mode\n";
+
+        if ($args{testing} == 1 || -e 't/testing.lck'){
+            # memory db testing
+            $self->{testing} = 1;
+            $self->{db} = $dbh;
+        }
+        if ($args{testing} == 2){
+            $self->{db} = DBI->connect(
+                # file db testing (events)
+                "dbi:SQLite:dbname=t/envui.db",
+                "",
+                "",
+                {RaiseError => 1}
+            ) or die $DBI::errstr;
+        }
     }
     else {
         $self->{db} = DBI->connect(
@@ -136,8 +155,8 @@ sub update {
     my ($self, $table, $col, $value, $where_col, $where_val) = @_;
 
     if (! defined $where_col){
-        my $sth = $self->{db}->prepare('UPDATE ? SET ?=?');
-        $sth->execute($table, $col, $value);
+        my $sth = $self->{db}->prepare("UPDATE $table SET $col=?");
+        $sth->execute($value);
     }
     else {
         my $sth = $self->{db}->prepare(
